@@ -7,13 +7,14 @@ import os
 import subprocess
 import sys
 import time
-
+# third-party module(s)
+import requests
+# neocortix modules
 import ncscli.batchRunner as batchRunner
 import ncscli.tellInstances as tellInstances
 import startForwarders  # expected to be in the same directory
 
 
-
 neoloadVersion = '7.7'  # '7.6' and '7.7 are currently supported
 nlWebWanted = False
 
@@ -93,13 +94,17 @@ def commandInstance( inst, cmd, timeLimit ):
 
 def configureAgent( inst, port, timeLimit=500 ):
     iid = inst['instanceId']
-    logger.info( 'would configure agent on instance %s for port %d', iid[0:16], port )
+    logger.debug( 'would configure agent on instance %s for port %d', iid[0:16], port )
     rc = 1
     # generate a command to modify agent.properties on the instance
-    #workerHost = inst['ssh']['host']
-    cmd = "sed -i 's/NCS_LG_PORT/%d/' ~/neoload%s/conf/agent.properties" % (port, neoloadVersion)
+    configDirPath = '~/neoload%s/conf' % neoloadVersion
+    if nlWebWanted:
+        cmd = "cat %s/nlweb.properties >> %s/agent.properties" % tuple( [configDirPath]*2 )
+    else:
+        cmd = "using standalone NeoLoad"
+    cmd += " && sed -i 's/NCS_LG_PORT/%d/' ~/neoload%s/conf/agent.properties" % (port, neoloadVersion)
     cmd += " && sed -i 's/NCS_LG_HOST/%s/' ~/neoload%s/conf/agent.properties" % (forwarderHost, neoloadVersion)
-    logger.info( 'cmd: %s', cmd )
+    logger.debug( 'cmd: %s', cmd )
     rc = commandInstance( inst, cmd, timeLimit=timeLimit )
     return rc
 
@@ -135,11 +140,25 @@ logger.setLevel(logging.INFO)
 dateTimeTag = datetime.datetime.now().strftime( '%Y-%m-%d_%H%M%S' )
 outDataDir = 'data/neoload_' + dateTimeTag
 
+# if you are forwarding from a host other than this one, change this forwarderHost-setting code
+forwarderHost = None
+try:
+    forwarderHost = requests.get( 'https://api.ipify.org' ).text
+except forwarderHost:
+    logger.warning( 'could not get public ip addr of this host')
+if not forwarderHost:
+    logger.error( 'forwarderHost not set')
+    exit(1)
+
+if nlWebWanted and not os.path.isfile( 'nlAgent/nlweb.properties'):
+    logger.error( 'the file nlAgent/nlweb.properties was not found')
+    sys.exit(1)
 try:
     # call runBatch to launch worker instances and install the load generator agent on them
     rc = batchRunner.runBatch(
         frameProcessor = neoloadFrameProcessor(),
         recruitOnly=True,
+        pushDeviceLocs=False,
         commonInFilePath = 'nlAgent',
         authToken = os.getenv('NCS_AUTH_TOKEN') or 'YourAuthTokenHere',
         encryptFiles=False,
@@ -147,11 +166,10 @@ try:
         instTimeLimit = 30*60,
         filter = '{"dpr": ">=48","ram:":">=2800000000","app-version": ">=2.1.11"}',
         outDataDir = outDataDir,
-        nWorkers = 10
+        nWorkers = 9
     )
     if rc == 0:
-        forwarderHost = 'localhost'
-        portRangeStart=7102
+        portRangeStart=7100
         launchedJsonFilePath = outDataDir +'/recruitLaunched.json'
         launchedInstances = []
         # get details of launched instances from the json file
@@ -162,7 +180,7 @@ try:
             except Exception as exc:
                 logger.warning( 'could not load json (%s) %s', type(exc), exc )
         startedInstances = [inst for inst in launchedInstances if inst['state'] == 'started' ]
-        logger.info( 'started %d instances', len(startedInstances) )
+        logger.info( '%d instances were launched', len(startedInstances) )
 
         if neoloadVersion == '7.7':
             agentLogFilePath = '/root/.neotys/neoload/v7.7/logs/agent.log'
@@ -186,7 +204,7 @@ try:
             timeLimit=30*60,
             knownHostsOnly=True
             )
-        logger.info( 'starter statuses: %s', stepStatuses )
+        logger.debug( 'starter statuses: %s', stepStatuses )
         # make a list of instances where the agent was started
         goodIids = []
         for status in stepStatuses:
@@ -224,15 +242,18 @@ try:
 
             # start the ssh port-forwarding
             logger.info( 'would forward ports for %d instances', len(goodInstances) )
-            startForwarders.startForwarders( goodInstances,
+            forwarders = startForwarders.startForwarders( goodInstances,
                 forwarderHost=forwarderHost,
                 portMap=portMap,
                 portRangeStart=portRangeStart, maxPort=portRangeStart+100,
                 forwardingCsvFilePath=outDataDir+'/agentForwarding.csv'
                 )
+            if len( forwarders ) < len( goodInstances ):
+                logger.warning( 'some instances could not be forwarded to' )
+            logger.debug( 'forwarders: %s', forwarders )
         if launchedInstances:
-            print( 'when you want to terminate these instances, use python3 terminateAgents.py "%s"'
-                % (outDataDir + '/recruitLaunched.json'))
+            print( 'when you want to terminate these instances, use %s terminateAgents.py "%s"'
+                % (sys.executable, outDataDir))
     sys.exit( rc )
 except KeyboardInterrupt:
     logger.warning( 'an interuption occurred')
